/****************************************************************************
** Meta object code from reading C++ file 'powerprofileadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "powerprofileadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerprofileadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19PowerProfileAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerProfileAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19PowerProfileAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerProfileAdaptor",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement.Actions.PowerProfile",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Solid.PowerManagement.Actions.PowerPro"
        "file\">\n    <method name=\"configuredProfile\">\n      <arg direc"
        "tion=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"curre"
        "ntProfile\">\n      <arg direction=\"out\" type=\"s\"/>\n    </met"
        "hod>\n    <method name=\"profileChoices\">\n      <arg direction=\""
        "out\" type=\"as\"/>\n    </method>\n    <method name=\"setProfile\""
        ">\n      <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <m"
        "ethod name=\"performanceInhibitedReason\">\n      <arg direction=\""
        "out\" type=\"s\"/>\n    </method>\n    <method name=\"performanceD"
        "egradedReason\">\n      <arg direction=\"out\" type=\"s\"/>\n    <"
        "/method>\n    <method name=\"profileHolds\">\n      <arg direction"
        "=\"out\" type=\"aa{sv}\"/>\n      <annotation value=\"QList&lt;QVa"
        "riantMap&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n  "
        "  </method>\n    <method name=\"holdProfile\">\n      <arg directi"
        "on=\"in\" type=\"s\" name=\"profile\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"reason\"/>\n      <arg direction=\"in\" type="
        "\"s\" name=\"application_id\"/>\n      <arg direction=\"out\" type"
        "=\"u\" name=\"cookie\"/>\n    </method>\n    <method name=\"releas"
        "eProfile\">\n      <arg direction=\"in\" type=\"u\" name=\"cookie\""
        "/>\n    </method>\n    <signal name=\"configuredProfileChanged\">\n"
        "      <arg direction=\"out\" type=\"s\"/>\n    </signal>\n    <sig"
        "nal name=\"currentProfileChanged\">\n      <arg direction=\"out\" "
        "type=\"s\"/>\n    </signal>\n    <signal name=\"profileChoicesChan"
        "ged\">\n      <arg direction=\"out\" type=\"as\"/>\n    </signal>\n"
        "    <signal name=\"performanceInhibitedReasonChanged\">\n      <ar"
        "g direction=\"out\" type=\"s\"/>\n    </signal>\n    <signal name="
        "\"performanceDegradedReasonChanged\">\n      <arg direction=\"out\""
        " type=\"s\"/>\n    </signal>\n    <signal name=\"profileHoldsChang"
        "ed\">\n      <arg direction=\"out\" type=\"aa{sv}\"/>\n      <anno"
        "tation value=\"QList&lt;QVariantMap&gt;\" name=\"org.qtproject.QtD"
        "Bus.QtTypeName.Out0\"/>\n    </signal>\n  </interface>\n",
        "configuredProfileChanged",
        "",
        "in0",
        "currentProfileChanged",
        "performanceDegradedReasonChanged",
        "performanceInhibitedReasonChanged",
        "profileChoicesChanged",
        "profileHoldsChanged",
        "QList<QVariantMap>",
        "configuredProfile",
        "currentProfile",
        "holdProfile",
        "profile",
        "reason",
        "application_id",
        "performanceDegradedReason",
        "performanceInhibitedReason",
        "profileChoices",
        "profileHolds",
        "releaseProfile",
        "cookie",
        "setProfile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configuredProfileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'currentProfileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'performanceDegradedReasonChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'performanceInhibitedReasonChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'profileChoicesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'profileHoldsChanged'
        QtMocHelpers::SignalData<void(const QList<QVariantMap> &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 7 },
        }}),
        // Slot 'configuredProfile'
        QtMocHelpers::SlotData<QString()>(14, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'currentProfile'
        QtMocHelpers::SlotData<QString()>(15, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'holdProfile'
        QtMocHelpers::SlotData<uint(const QString &, const QString &, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'performanceDegradedReason'
        QtMocHelpers::SlotData<QString()>(20, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'performanceInhibitedReason'
        QtMocHelpers::SlotData<QString()>(21, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'profileChoices'
        QtMocHelpers::SlotData<QStringList()>(22, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'profileHolds'
        QtMocHelpers::SlotData<QList<QVariantMap>()>(23, 6, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'releaseProfile'
        QtMocHelpers::SlotData<void(uint)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 25 },
        }}),
        // Slot 'setProfile'
        QtMocHelpers::SlotData<void(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PowerProfileAdaptor, qt_meta_tag_ZN19PowerProfileAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerProfileAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PowerProfileAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PowerProfileAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19PowerProfileAdaptorE_t>.metaTypes,
    nullptr
} };

void PowerProfileAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerProfileAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configuredProfileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->currentProfileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->performanceDegradedReasonChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->performanceInhibitedReasonChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->profileChoicesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->profileHoldsChanged((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1]))); break;
        case 6: { QString _r = _t->configuredProfile();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->currentProfile();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { uint _r = _t->holdProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->performanceDegradedReason();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->performanceInhibitedReason();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QStringList _r = _t->profileChoices();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 12: { QList<QVariantMap> _r = _t->profileHolds();
            if (_a[0]) *reinterpret_cast<QList<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->releaseProfile((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 14: _t->setProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerProfileAdaptor::*)(const QString & )>(_a, &PowerProfileAdaptor::configuredProfileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfileAdaptor::*)(const QString & )>(_a, &PowerProfileAdaptor::currentProfileChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfileAdaptor::*)(const QString & )>(_a, &PowerProfileAdaptor::performanceDegradedReasonChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfileAdaptor::*)(const QString & )>(_a, &PowerProfileAdaptor::performanceInhibitedReasonChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfileAdaptor::*)(const QStringList & )>(_a, &PowerProfileAdaptor::profileChoicesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfileAdaptor::*)(const QList<QVariantMap> & )>(_a, &PowerProfileAdaptor::profileHoldsChanged, 5))
            return;
    }
}

const QMetaObject *PowerProfileAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerProfileAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PowerProfileAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PowerProfileAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void PowerProfileAdaptor::configuredProfileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerProfileAdaptor::currentProfileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerProfileAdaptor::performanceDegradedReasonChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerProfileAdaptor::performanceInhibitedReasonChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerProfileAdaptor::profileChoicesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PowerProfileAdaptor::profileHoldsChanged(const QList<QVariantMap> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
