/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.PowerManagement.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "powermanagementfdoadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PowerManagementFdoAdaptor
 */

PowerManagementFdoAdaptor::PowerManagementFdoAdaptor(PowerDevil::FdoConnector *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PowerManagementFdoAdaptor::~PowerManagementFdoAdaptor()
{
    // destructor
}

bool PowerManagementFdoAdaptor::CanHibernate()
{
    // handle method call org.freedesktop.PowerManagement.CanHibernate
    return parent()->CanHibernate();
}

bool PowerManagementFdoAdaptor::CanHybridSuspend()
{
    // handle method call org.freedesktop.PowerManagement.CanHybridSuspend
    return parent()->CanHybridSuspend();
}

bool PowerManagementFdoAdaptor::CanSuspend()
{
    // handle method call org.freedesktop.PowerManagement.CanSuspend
    return parent()->CanSuspend();
}

bool PowerManagementFdoAdaptor::CanSuspendThenHibernate()
{
    // handle method call org.freedesktop.PowerManagement.CanSuspendThenHibernate
    return parent()->CanSuspendThenHibernate();
}

bool PowerManagementFdoAdaptor::GetPowerSaveStatus()
{
    // handle method call org.freedesktop.PowerManagement.GetPowerSaveStatus
    return parent()->GetPowerSaveStatus();
}

void PowerManagementFdoAdaptor::Hibernate()
{
    // handle method call org.freedesktop.PowerManagement.Hibernate
    parent()->Hibernate();
}

void PowerManagementFdoAdaptor::Suspend()
{
    // handle method call org.freedesktop.PowerManagement.Suspend
    parent()->Suspend();
}


#include "moc_powermanagementfdoadaptor.cpp"
