/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ScreenBrightness.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SCREENBRIGHTNESSADAPTOR_H
#define SCREENBRIGHTNESSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "powerdevilscreenbrightnessagent.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.ScreenBrightness
 */
class ScreenBrightnessAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.ScreenBrightness")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.ScreenBrightness\">\n"
"    <property access=\"read\" type=\"as\" name=\"DisplaysDBusNames\">\n"
"    </property>\n"
"    <signal name=\"DisplayAdded\">\n"
"      <arg type=\"s\" name=\"display_dbus_name\"/>\n"
"    </signal>\n"
"    <signal name=\"DisplayRemoved\">\n"
"      <arg type=\"s\" name=\"display_dbus_name\"/>\n"
"    </signal>\n"
"    <method name=\"AdjustBrightnessRatio\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"delta\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"    </method>\n"
"    <method name=\"AdjustBrightnessRatioWithContext\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"delta\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"source_client_context\"/>\n"
"    </method>\n"
"    <method name=\"AdjustBrightnessStep\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"step_action\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"    </method>\n"
"    <method name=\"AdjustBrightnessStepWithContext\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"step_action\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"source_client_context\"/>\n"
"    </method>\n"
"    <signal name=\"BrightnessChanged\">\n"
"      <arg type=\"s\" name=\"display_dbus_name\"/>\n"
"      <arg type=\"i\" name=\"brightness\"/>\n"
"      <arg type=\"s\" name=\"source_client_name\"/>\n"
"      <arg type=\"s\" name=\"source_client_context\"/>\n"
"    </signal>\n"
"    <signal name=\"BrightnessRangeChanged\">\n"
"      <arg type=\"s\" name=\"display_dbus_name\"/>\n"
"      <arg type=\"i\" name=\"max_brightness\"/>\n"
"      <arg type=\"i\" name=\"brightness\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    ScreenBrightnessAdaptor(PowerDevil::ScreenBrightnessAgent *parent);
    ~ScreenBrightnessAdaptor() override;

    inline PowerDevil::ScreenBrightnessAgent *parent() const
    { return static_cast<PowerDevil::ScreenBrightnessAgent *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QStringList DisplaysDBusNames READ displaysDBusNames)
    QStringList displaysDBusNames() const;

public Q_SLOTS: // METHODS
    void AdjustBrightnessRatio(double delta, uint flags);
    void AdjustBrightnessRatioWithContext(double delta, uint flags, const QString &source_client_context);
    void AdjustBrightnessStep(uint step_action, uint flags);
    void AdjustBrightnessStepWithContext(uint step_action, uint flags, const QString &source_client_context);
Q_SIGNALS: // SIGNALS
    void BrightnessChanged(const QString &display_dbus_name, int brightness, const QString &source_client_name, const QString &source_client_context);
    void BrightnessRangeChanged(const QString &display_dbus_name, int max_brightness, int brightness);
    void DisplayAdded(const QString &display_dbus_name);
    void DisplayRemoved(const QString &display_dbus_name);
};

#endif
