/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "keyboardbrightnesscontroladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KeyboardBrightnessControlAdaptor
 */

KeyboardBrightnessControlAdaptor::KeyboardBrightnessControlAdaptor(PowerDevil::BundledActions::KeyboardBrightnessControl *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KeyboardBrightnessControlAdaptor::~KeyboardBrightnessControlAdaptor()
{
    // destructor
}

int KeyboardBrightnessControlAdaptor::keyboardBrightness()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl.keyboardBrightness
    return parent()->keyboardBrightness();
}

int KeyboardBrightnessControlAdaptor::keyboardBrightnessMax()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl.keyboardBrightnessMax
    return parent()->keyboardBrightnessMax();
}

int KeyboardBrightnessControlAdaptor::keyboardBrightnessSteps()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl.keyboardBrightnessSteps
    return parent()->keyboardBrightnessSteps();
}

void KeyboardBrightnessControlAdaptor::setKeyboardBrightness(int in0)
{
    // handle method call org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl.setKeyboardBrightness
    parent()->setKeyboardBrightness(in0);
}

void KeyboardBrightnessControlAdaptor::setKeyboardBrightnessSilent(int in0)
{
    // handle method call org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl.setKeyboardBrightnessSilent
    parent()->setKeyboardBrightnessSilent(in0);
}


#include "moc_keyboardbrightnesscontroladaptor.cpp"
