// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_APPLETS_BRIGHTNESS_BRIGHTNESSCONTROLPLUGIN_DEBUG_H
#define ECM_QLOGGINGCATEGORY_APPLETS_BRIGHTNESS_BRIGHTNESSCONTROLPLUGIN_DEBUG_H

#include <QLoggingCategory>
 namespace APPLETS {
Q_DECLARE_LOGGING_CATEGORY(BRIGHTNESS)
} 

#endif
