// This file is generated by kconfig_compiler_kf6 from brightness_kdeglobalssettings.kcfg.
// All changes you do to this file will be lost.

#include "brightness_kdeglobalssettings.h"

BrightnessGlobalsSettings::BrightnessGlobalsSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kdeglobals" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&BrightnessGlobalsSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "KDE" ) );

  KConfigCompilerSignallingItem  *itemLookAndFeelPackage;
  KConfigSkeleton::ItemString  *innerItemLookAndFeelPackage;
  innerItemLookAndFeelPackage = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LookAndFeelPackage" ), mLookAndFeelPackage, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemLookAndFeelPackage = new KConfigCompilerSignallingItem(innerItemLookAndFeelPackage, this, notifyFunction, signalLookAndFeelPackageChanged);
  addItem( itemLookAndFeelPackage, QStringLiteral( "lookAndFeelPackage" ) );
  KConfigCompilerSignallingItem  *itemDefaultLightLookAndFeel;
  KConfigSkeleton::ItemString  *innerItemDefaultLightLookAndFeel;
  innerItemDefaultLightLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultLightLookAndFeel" ), mDefaultLightLookAndFeel, QStringLiteral( "org.kde.breeze.desktop" ) );
  itemDefaultLightLookAndFeel = new KConfigCompilerSignallingItem(innerItemDefaultLightLookAndFeel, this, notifyFunction, signalDefaultLightLookAndFeelChanged);
  itemDefaultLightLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultLightLookAndFeel, QStringLiteral( "defaultLightLookAndFeel" ) );
  KConfigCompilerSignallingItem  *itemDefaultDarkLookAndFeel;
  KConfigSkeleton::ItemString  *innerItemDefaultDarkLookAndFeel;
  innerItemDefaultDarkLookAndFeel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "DefaultDarkLookAndFeel" ), mDefaultDarkLookAndFeel, QStringLiteral( "org.kde.breezedark.desktop" ) );
  itemDefaultDarkLookAndFeel = new KConfigCompilerSignallingItem(innerItemDefaultDarkLookAndFeel, this, notifyFunction, signalDefaultDarkLookAndFeelChanged);
  itemDefaultDarkLookAndFeel->setWriteFlags(KConfigBase::Notify);
  addItem( itemDefaultDarkLookAndFeel, QStringLiteral( "defaultDarkLookAndFeel" ) );
}

QString BrightnessGlobalsSettings::defaultLookAndFeelPackageValue_helper() const
{

  return QStringLiteral( "org.kde.breeze.desktop" );
}

QString BrightnessGlobalsSettings::defaultDefaultLightLookAndFeelValue_helper() const
{

  return QStringLiteral( "org.kde.breeze.desktop" );
}

QString BrightnessGlobalsSettings::defaultDefaultDarkLookAndFeelValue_helper() const
{

  return QStringLiteral( "org.kde.breezedark.desktop" );
}

BrightnessGlobalsSettings::~BrightnessGlobalsSettings()
{
}


void BrightnessGlobalsSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalLookAndFeelPackageChanged:
    Q_EMIT lookAndFeelPackageChanged();
    break;
  case signalDefaultLightLookAndFeelChanged:
    Q_EMIT defaultLightLookAndFeelChanged();
    break;
  case signalDefaultDarkLookAndFeelChanged:
    Q_EMIT defaultDarkLookAndFeelChanged();
    break;
  }
}
