/****************************************************************************
** Meta object code from reading C++ file 'powermanagementinhibitadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "powermanagementinhibitadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powermanagementinhibitadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29PowerManagementInhibitAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerManagementInhibitAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN29PowerManagementInhibitAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerManagementInhibitAdaptor",
        "D-Bus Interface",
        "org.freedesktop.PowerManagement.Inhibit",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.PowerManagement.Inhibit\">\n  "
        "  <method name=\"Inhibit\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"application\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"reason\"/>\n      <arg direction=\"out\" type=\"u\" name=\"co"
        "okie\"/>\n    </method>\n    <method name=\"UnInhibit\">\n      <a"
        "rg direction=\"in\" type=\"u\" name=\"cookie\"/>\n    </method>\n "
        "   <signal name=\"HasInhibitChanged\">\n      <arg direction=\"out"
        "\" type=\"b\" name=\"has_inhibit\"/>\n    </signal>\n    <method n"
        "ame=\"HasInhibit\">\n      <arg direction=\"out\" type=\"b\" name="
        "\"has_inhibit\"/>\n    </method>\n  </interface>\n",
        "HasInhibitChanged",
        "",
        "has_inhibit",
        "HasInhibit",
        "Inhibit",
        "application",
        "reason",
        "UnInhibit",
        "cookie"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'HasInhibitChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'HasInhibit'
        QtMocHelpers::SlotData<bool()>(8, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'Inhibit'
        QtMocHelpers::SlotData<uint(const QString &, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'UnInhibit'
        QtMocHelpers::SlotData<void(uint)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PowerManagementInhibitAdaptor, qt_meta_tag_ZN29PowerManagementInhibitAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerManagementInhibitAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29PowerManagementInhibitAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29PowerManagementInhibitAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29PowerManagementInhibitAdaptorE_t>.metaTypes,
    nullptr
} };

void PowerManagementInhibitAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerManagementInhibitAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->HasInhibitChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: { bool _r = _t->HasInhibit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { uint _r = _t->Inhibit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->UnInhibit((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerManagementInhibitAdaptor::*)(bool )>(_a, &PowerManagementInhibitAdaptor::HasInhibitChanged, 0))
            return;
    }
}

const QMetaObject *PowerManagementInhibitAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerManagementInhibitAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29PowerManagementInhibitAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PowerManagementInhibitAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void PowerManagementInhibitAdaptor::HasInhibitChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
