// This file was generated by qtwaylandscanner
// source file is kde-external-brightness-v1.xml

#ifndef QT_WAYLAND_KDE_EXTERNAL_BRIGHTNESS_V1
#define QT_WAYLAND_KDE_EXTERNAL_BRIGHTNESS_V1

#include "wayland-kde-external-brightness-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  kde_external_brightness_v1
    {
    public:
        kde_external_brightness_v1(struct ::wl_registry *registry, uint32_t id, int version);
        kde_external_brightness_v1(struct ::kde_external_brightness_v1 *object);
        kde_external_brightness_v1();

        virtual ~kde_external_brightness_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::kde_external_brightness_v1 *object);

        struct ::kde_external_brightness_v1 *object() { return m_kde_external_brightness_v1; }
        const struct ::kde_external_brightness_v1 *object() const { return m_kde_external_brightness_v1; }
        static kde_external_brightness_v1 *fromObject(struct ::kde_external_brightness_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();
        struct ::kde_external_brightness_device_v1 *create_brightness_control();

    private:
        struct ::kde_external_brightness_v1 *m_kde_external_brightness_v1;
    };

    class  kde_external_brightness_device_v1
    {
    public:
        kde_external_brightness_device_v1(struct ::wl_registry *registry, uint32_t id, int version);
        kde_external_brightness_device_v1(struct ::kde_external_brightness_device_v1 *object);
        kde_external_brightness_device_v1();

        virtual ~kde_external_brightness_device_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::kde_external_brightness_device_v1 *object);

        struct ::kde_external_brightness_device_v1 *object() { return m_kde_external_brightness_device_v1; }
        const struct ::kde_external_brightness_device_v1 *object() const { return m_kde_external_brightness_device_v1; }
        static kde_external_brightness_device_v1 *fromObject(struct ::kde_external_brightness_device_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void destroy();
        void set_internal(uint32_t internal);
        void set_edid(const QString &string);
        void set_max_brightness(uint32_t value);
        void commit();
        void set_observed_brightness(uint32_t value);
        void set_uses_ddc_ci(uint32_t value);

    protected:
        virtual void kde_external_brightness_device_v1_requested_brightness(uint32_t value);

    private:
        void init_listener();
        static const struct kde_external_brightness_device_v1_listener m_kde_external_brightness_device_v1_listener;
        static void handle_requested_brightness(
            void *data,
            struct ::kde_external_brightness_device_v1 *object,
            uint32_t value);
        struct ::kde_external_brightness_device_v1 *m_kde_external_brightness_device_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
