/****************************************************************************
** Meta object code from reading C++ file 'keyboardbrightnesscontroladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "keyboardbrightnesscontroladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardbrightnesscontroladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32KeyboardBrightnessControlAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardBrightnessControlAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN32KeyboardBrightnessControlAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardBrightnessControlAdaptor",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Solid.PowerManagement.Actions.Keyboard"
        "BrightnessControl\">\n    <method name=\"setKeyboardBrightness\">\n"
        "      <arg direction=\"in\" type=\"i\"/>\n    </method>\n    <meth"
        "od name=\"setKeyboardBrightnessSilent\">\n      <arg direction=\"i"
        "n\" type=\"i\"/>\n    </method>\n    <method name=\"keyboardBright"
        "ness\">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n"
        "    <method name=\"keyboardBrightnessMax\">\n      <arg direction="
        "\"out\" type=\"i\"/>\n    </method>\n    <signal name=\"keyboardBr"
        "ightnessChanged\">\n      <arg direction=\"out\" type=\"i\"/>\n   "
        " </signal>\n    <signal name=\"keyboardBrightnessMaxChanged\">\n  "
        "    <arg direction=\"out\" type=\"i\"/>\n    </signal>\n    <metho"
        "d name=\"keyboardBrightnessSteps\">\n      <arg direction=\"out\" "
        "type=\"i\"/>\n    </method>\n  </interface>\n",
        "keyboardBrightnessChanged",
        "",
        "in0",
        "keyboardBrightnessMaxChanged",
        "keyboardBrightness",
        "keyboardBrightnessMax",
        "keyboardBrightnessSteps",
        "setKeyboardBrightness",
        "setKeyboardBrightnessSilent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keyboardBrightnessChanged'
        QtMocHelpers::SignalData<void(int)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'keyboardBrightnessMaxChanged'
        QtMocHelpers::SignalData<void(int)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'keyboardBrightness'
        QtMocHelpers::SlotData<int()>(9, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'keyboardBrightnessMax'
        QtMocHelpers::SlotData<int()>(10, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'keyboardBrightnessSteps'
        QtMocHelpers::SlotData<int()>(11, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setKeyboardBrightness'
        QtMocHelpers::SlotData<void(int)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setKeyboardBrightnessSilent'
        QtMocHelpers::SlotData<void(int)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KeyboardBrightnessControlAdaptor, qt_meta_tag_ZN32KeyboardBrightnessControlAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KeyboardBrightnessControlAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32KeyboardBrightnessControlAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32KeyboardBrightnessControlAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32KeyboardBrightnessControlAdaptorE_t>.metaTypes,
    nullptr
} };

void KeyboardBrightnessControlAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardBrightnessControlAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keyboardBrightnessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->keyboardBrightnessMaxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: { int _r = _t->keyboardBrightness();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->keyboardBrightnessMax();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->keyboardBrightnessSteps();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setKeyboardBrightness((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setKeyboardBrightnessSilent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardBrightnessControlAdaptor::*)(int )>(_a, &KeyboardBrightnessControlAdaptor::keyboardBrightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardBrightnessControlAdaptor::*)(int )>(_a, &KeyboardBrightnessControlAdaptor::keyboardBrightnessMaxChanged, 1))
            return;
    }
}

const QMetaObject *KeyboardBrightnessControlAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardBrightnessControlAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32KeyboardBrightnessControlAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KeyboardBrightnessControlAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KeyboardBrightnessControlAdaptor::keyboardBrightnessChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KeyboardBrightnessControlAdaptor::keyboardBrightnessMaxChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
