/****************************************************************************
** Meta object code from reading C++ file 'powermanagementadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "powermanagementadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powermanagementadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22PowerManagementAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerManagementAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN22PowerManagementAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerManagementAdaptor",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Solid.PowerManagement\">\n    <method "
        "name=\"refreshStatus\"/>\n    <method name=\"reparseConfiguration\""
        "/>\n    <method name=\"backendCapabilities\">\n      <arg directio"
        "n=\"out\" type=\"u\"/>\n    </method>\n    <method name=\"loadProf"
        "ile\">\n      <arg direction=\"in\" type=\"b\"/>\n    </method>\n "
        "   <method name=\"currentProfile\">\n      <arg direction=\"out\" "
        "type=\"s\"/>\n    </method>\n    <method name=\"batteryRemainingTi"
        "me\">\n      <arg direction=\"out\" type=\"t\"/>\n    </method>\n "
        "   <method name=\"smoothedBatteryRemainingTime\">\n      <arg dire"
        "ction=\"out\" type=\"t\"/>\n    </method>\n    <method name=\"isLi"
        "dClosed\">\n      <arg direction=\"out\" type=\"b\"/>\n    </metho"
        "d>\n    <method name=\"isLidPresent\">\n      <arg direction=\"out"
        "\" type=\"b\"/>\n    </method>\n    <method name=\"isActionSupport"
        "ed\">\n      <arg direction=\"in\" type=\"s\"/>\n      <arg direct"
        "ion=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"hasDua"
        "lGpu\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n"
        "    <method name=\"isBatteryConservationModeEnabled\">\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "chargeStartThreshold\">\n      <arg direction=\"out\" type=\"i\"/>"
        "\n    </method>\n    <method name=\"chargeStopThreshold\">\n      "
        "<arg direction=\"out\" type=\"i\"/>\n    </method>\n    <method na"
        "me=\"scheduleWakeup\">\n      <arg direction=\"out\" type=\"u\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"service\"/>\n      <"
        "arg direction=\"in\" type=\"o\" name=\"path\"/>\n      <arg direct"
        "ion=\"in\" type=\"t\" name=\"timestamp\"/>\n    </method>\n    <me"
        "thod name=\"wakeup\"/>\n    <method name=\"clearWakeup\">\n      <"
        "arg direction=\"in\" type=\"i\"/>\n    </method>\n    <signal name"
        "=\"profileChanged\">\n      <arg direction=\"out\" type=\"s\"/>\n "
        "   </signal>\n    <signal name=\"configurationReloaded\"/>\n    <s"
        "ignal name=\"batteryRemainingTimeChanged\">\n      <arg direction="
        "\"out\" type=\"t\"/>\n    </signal>\n    <signal name=\"smoothedBa"
        "tteryRemainingTimeChanged\">\n      <arg direction=\"out\" type=\""
        "t\"/>\n    </signal>\n    <signal name=\"lidClosedChanged\">\n    "
        "  <arg direction=\"out\" type=\"b\"/>\n    </signal>\n    <signal "
        "name=\"batteryConservationModeChanged\">\n      <arg direction=\"o"
        "ut\" type=\"b\"/>\n    </signal>\n    <signal name=\"chargeStartTh"
        "resholdChanged\">\n      <arg direction=\"out\" type=\"i\"/>\n    "
        "</signal>\n    <signal name=\"chargeStopThresholdChanged\">\n     "
        " <arg direction=\"out\" type=\"i\"/>\n    </signal>\n    <signal n"
        "ame=\"supportedActionsChanged\"/>\n  </interface>\n",
        "batteryConservationModeChanged",
        "",
        "in0",
        "batteryRemainingTimeChanged",
        "chargeStartThresholdChanged",
        "chargeStopThresholdChanged",
        "configurationReloaded",
        "lidClosedChanged",
        "profileChanged",
        "smoothedBatteryRemainingTimeChanged",
        "supportedActionsChanged",
        "backendCapabilities",
        "batteryRemainingTime",
        "chargeStartThreshold",
        "chargeStopThreshold",
        "clearWakeup",
        "currentProfile",
        "hasDualGpu",
        "isActionSupported",
        "isBatteryConservationModeEnabled",
        "isLidClosed",
        "isLidPresent",
        "loadProfile",
        "refreshStatus",
        "reparseConfiguration",
        "scheduleWakeup",
        "service",
        "QDBusObjectPath",
        "path",
        "timestamp",
        "smoothedBatteryRemainingTime",
        "wakeup"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'batteryConservationModeChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'batteryRemainingTimeChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Signal 'chargeStartThresholdChanged'
        QtMocHelpers::SignalData<void(int)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'chargeStopThresholdChanged'
        QtMocHelpers::SignalData<void(int)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'configurationReloaded'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lidClosedChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'smoothedBatteryRemainingTimeChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Signal 'supportedActionsChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'backendCapabilities'
        QtMocHelpers::SlotData<uint()>(16, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'batteryRemainingTime'
        QtMocHelpers::SlotData<qulonglong()>(17, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'chargeStartThreshold'
        QtMocHelpers::SlotData<int()>(18, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'chargeStopThreshold'
        QtMocHelpers::SlotData<int()>(19, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'clearWakeup'
        QtMocHelpers::SlotData<void(int)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'currentProfile'
        QtMocHelpers::SlotData<QString()>(21, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'hasDualGpu'
        QtMocHelpers::SlotData<bool()>(22, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isActionSupported'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'isBatteryConservationModeEnabled'
        QtMocHelpers::SlotData<bool()>(24, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isLidClosed'
        QtMocHelpers::SlotData<bool()>(25, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isLidPresent'
        QtMocHelpers::SlotData<bool()>(26, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'loadProfile'
        QtMocHelpers::SlotData<void(bool)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'refreshStatus'
        QtMocHelpers::SlotData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reparseConfiguration'
        QtMocHelpers::SlotData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scheduleWakeup'
        QtMocHelpers::SlotData<uint(const QString &, const QDBusObjectPath &, qulonglong)>(30, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 31 }, { 0x80000000 | 32, 33 }, { QMetaType::ULongLong, 34 },
        }}),
        // Slot 'smoothedBatteryRemainingTime'
        QtMocHelpers::SlotData<qulonglong()>(35, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'wakeup'
        QtMocHelpers::SlotData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PowerManagementAdaptor, qt_meta_tag_ZN22PowerManagementAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerManagementAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PowerManagementAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PowerManagementAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22PowerManagementAdaptorE_t>.metaTypes,
    nullptr
} };

void PowerManagementAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerManagementAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->batteryConservationModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->batteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 2: _t->chargeStartThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->chargeStopThresholdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->configurationReloaded(); break;
        case 5: _t->lidClosedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->profileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->smoothedBatteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 8: _t->supportedActionsChanged(); break;
        case 9: { uint _r = _t->backendCapabilities();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 10: { qulonglong _r = _t->batteryRemainingTime();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->chargeStartThreshold();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->chargeStopThreshold();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->clearWakeup((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: { QString _r = _t->currentProfile();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->hasDualGpu();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->isActionSupported((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->isBatteryConservationModeEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->isLidClosed();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->isLidPresent();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->loadProfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->refreshStatus(); break;
        case 22: _t->reparseConfiguration(); break;
        case 23: { uint _r = _t->scheduleWakeup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 24: { qulonglong _r = _t->smoothedBatteryRemainingTime();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->wakeup(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)(bool )>(_a, &PowerManagementAdaptor::batteryConservationModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)(qulonglong )>(_a, &PowerManagementAdaptor::batteryRemainingTimeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)(int )>(_a, &PowerManagementAdaptor::chargeStartThresholdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)(int )>(_a, &PowerManagementAdaptor::chargeStopThresholdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)()>(_a, &PowerManagementAdaptor::configurationReloaded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)(bool )>(_a, &PowerManagementAdaptor::lidClosedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)(const QString & )>(_a, &PowerManagementAdaptor::profileChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)(qulonglong )>(_a, &PowerManagementAdaptor::smoothedBatteryRemainingTimeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementAdaptor::*)()>(_a, &PowerManagementAdaptor::supportedActionsChanged, 8))
            return;
    }
}

const QMetaObject *PowerManagementAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerManagementAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22PowerManagementAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PowerManagementAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void PowerManagementAdaptor::batteryConservationModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerManagementAdaptor::batteryRemainingTimeChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerManagementAdaptor::chargeStartThresholdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerManagementAdaptor::chargeStopThresholdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerManagementAdaptor::configurationReloaded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PowerManagementAdaptor::lidClosedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PowerManagementAdaptor::profileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PowerManagementAdaptor::smoothedBatteryRemainingTimeChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PowerManagementAdaptor::supportedActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
