/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.HandleButtonEvents.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef HANDLEBUTTONEVENTSADAPTOR_H
#define HANDLEBUTTONEVENTSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "handlebuttonevents.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Solid.PowerManagement.Actions.HandleButtonEvents
 */
class HandleButtonEventsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement.Actions.HandleButtonEvents")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Solid.PowerManagement.Actions.HandleButtonEvents\">\n"
"    <method name=\"lidAction\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"triggersLidAction\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"triggersLidActionChanged\">\n"
"      <arg type=\"b\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    HandleButtonEventsAdaptor(PowerDevil::BundledActions::HandleButtonEvents *parent);
    ~HandleButtonEventsAdaptor() override;

    inline PowerDevil::BundledActions::HandleButtonEvents *parent() const
    { return static_cast<PowerDevil::BundledActions::HandleButtonEvents *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    int lidAction();
    bool triggersLidAction();
Q_SIGNALS: // SIGNALS
    void triggersLidActionChanged(bool in0);
};

#endif
