// This file is autogenerated. Changes will be overwritten.
#include "EJRQKI7XPS/moc_PowerDevilActivitySettings.cpp"
#include "EJRQKI7XPS/moc_PowerDevilGlobalSettings.cpp"
#include "EJRQKI7XPS/moc_PowerDevilProfileSettings.cpp"
