/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.PowerManagement.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef POWERMANAGEMENTFDOADAPTOR_H
#define POWERMANAGEMENTFDOADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "powerdevilfdoconnector.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.PowerManagement
 */
class PowerManagementFdoAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.PowerManagement")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.PowerManagement\">\n"
"    <signal name=\"CanSuspendChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_suspend\"/>\n"
"    </signal>\n"
"    <signal name=\"CanHibernateChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_hibernate\"/>\n"
"    </signal>\n"
"    <signal name=\"CanHybridSuspendChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_hybrid_suspend\"/>\n"
"    </signal>\n"
"    <signal name=\"CanSuspendThenHibernateChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_suspend_then_hibernate\"/>\n"
"    </signal>\n"
"    <signal name=\"PowerSaveStatusChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"save_power\"/>\n"
"    </signal>\n"
"    <method name=\"Suspend\"/>\n"
"    <method name=\"Hibernate\"/>\n"
"    <method name=\"CanSuspend\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_suspend\"/>\n"
"    </method>\n"
"    <method name=\"CanHibernate\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_hibernate\"/>\n"
"    </method>\n"
"    <method name=\"CanHybridSuspend\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_hybrid_suspend\"/>\n"
"    </method>\n"
"    <method name=\"CanSuspendThenHibernate\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"can_suspend_then_hibernate\"/>\n"
"    </method>\n"
"    <method name=\"GetPowerSaveStatus\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"save_power\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    PowerManagementFdoAdaptor(PowerDevil::FdoConnector *parent);
    ~PowerManagementFdoAdaptor() override;

    inline PowerDevil::FdoConnector *parent() const
    { return static_cast<PowerDevil::FdoConnector *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool CanHibernate();
    bool CanHybridSuspend();
    bool CanSuspend();
    bool CanSuspendThenHibernate();
    bool GetPowerSaveStatus();
    void Hibernate();
    void Suspend();
Q_SIGNALS: // SIGNALS
    void CanHibernateChanged(bool can_hibernate);
    void CanHybridSuspendChanged(bool can_hybrid_suspend);
    void CanSuspendChanged(bool can_suspend);
    void CanSuspendThenHibernateChanged(bool can_suspend_then_hibernate);
    void PowerSaveStatusChanged(bool save_power);
};

#endif
