/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.PowerManagement.Inhibit.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "powermanagementinhibitadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PowerManagementInhibitAdaptor
 */

PowerManagementInhibitAdaptor::PowerManagementInhibitAdaptor(PowerDevil::FdoConnector *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PowerManagementInhibitAdaptor::~PowerManagementInhibitAdaptor()
{
    // destructor
}

bool PowerManagementInhibitAdaptor::HasInhibit()
{
    // handle method call org.freedesktop.PowerManagement.Inhibit.HasInhibit
    return parent()->HasInhibit();
}

uint PowerManagementInhibitAdaptor::Inhibit(const QString &application, const QString &reason)
{
    // handle method call org.freedesktop.PowerManagement.Inhibit.Inhibit
    return parent()->Inhibit(application, reason);
}

void PowerManagementInhibitAdaptor::UnInhibit(uint cookie)
{
    // handle method call org.freedesktop.PowerManagement.Inhibit.UnInhibit
    parent()->UnInhibit(cookie);
}


#include "moc_powermanagementinhibitadaptor.cpp"
