/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.BrightnessControl.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "brightnesscontroladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class BrightnessControlAdaptor
 */

BrightnessControlAdaptor::BrightnessControlAdaptor(PowerDevil::BundledActions::BrightnessControl *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

BrightnessControlAdaptor::~BrightnessControlAdaptor()
{
    // destructor
}

int BrightnessControlAdaptor::brightness()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.BrightnessControl.brightness
    return parent()->brightness();
}

int BrightnessControlAdaptor::brightnessMax()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.BrightnessControl.brightnessMax
    return parent()->brightnessMax();
}

int BrightnessControlAdaptor::brightnessMin()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.BrightnessControl.brightnessMin
    return parent()->brightnessMin();
}

int BrightnessControlAdaptor::brightnessSteps()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.BrightnessControl.brightnessSteps
    return parent()->brightnessSteps();
}

int BrightnessControlAdaptor::knownSafeBrightnessMin()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.BrightnessControl.knownSafeBrightnessMin
    return parent()->knownSafeBrightnessMin();
}

void BrightnessControlAdaptor::setBrightness(int in0)
{
    // handle method call org.kde.Solid.PowerManagement.Actions.BrightnessControl.setBrightness
    parent()->setBrightness(in0);
}

void BrightnessControlAdaptor::setBrightnessSilent(int in0)
{
    // handle method call org.kde.Solid.PowerManagement.Actions.BrightnessControl.setBrightnessSilent
    parent()->setBrightnessSilent(in0);
}


#include "moc_brightnesscontroladaptor.cpp"
