/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "powermanagementadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PowerManagementAdaptor
 */

PowerManagementAdaptor::PowerManagementAdaptor(PowerDevil::Core *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PowerManagementAdaptor::~PowerManagementAdaptor()
{
    // destructor
}

uint PowerManagementAdaptor::backendCapabilities()
{
    // handle method call org.kde.Solid.PowerManagement.backendCapabilities
    return parent()->backendCapabilities();
}

qulonglong PowerManagementAdaptor::batteryRemainingTime()
{
    // handle method call org.kde.Solid.PowerManagement.batteryRemainingTime
    return parent()->batteryRemainingTime();
}

int PowerManagementAdaptor::chargeStartThreshold()
{
    // handle method call org.kde.Solid.PowerManagement.chargeStartThreshold
    return parent()->chargeStartThreshold();
}

int PowerManagementAdaptor::chargeStopThreshold()
{
    // handle method call org.kde.Solid.PowerManagement.chargeStopThreshold
    return parent()->chargeStopThreshold();
}

void PowerManagementAdaptor::clearWakeup(int in0)
{
    // handle method call org.kde.Solid.PowerManagement.clearWakeup
    parent()->clearWakeup(in0);
}

QString PowerManagementAdaptor::currentProfile()
{
    // handle method call org.kde.Solid.PowerManagement.currentProfile
    return parent()->currentProfile();
}

bool PowerManagementAdaptor::hasDualGpu()
{
    // handle method call org.kde.Solid.PowerManagement.hasDualGpu
    return parent()->hasDualGpu();
}

bool PowerManagementAdaptor::isActionSupported(const QString &in0)
{
    // handle method call org.kde.Solid.PowerManagement.isActionSupported
    return parent()->isActionSupported(in0);
}

bool PowerManagementAdaptor::isBatteryConservationModeEnabled()
{
    // handle method call org.kde.Solid.PowerManagement.isBatteryConservationModeEnabled
    return parent()->isBatteryConservationModeEnabled();
}

bool PowerManagementAdaptor::isLidClosed()
{
    // handle method call org.kde.Solid.PowerManagement.isLidClosed
    return parent()->isLidClosed();
}

bool PowerManagementAdaptor::isLidPresent()
{
    // handle method call org.kde.Solid.PowerManagement.isLidPresent
    return parent()->isLidPresent();
}

void PowerManagementAdaptor::loadProfile(bool in0)
{
    // handle method call org.kde.Solid.PowerManagement.loadProfile
    parent()->loadProfile(in0);
}

void PowerManagementAdaptor::refreshStatus()
{
    // handle method call org.kde.Solid.PowerManagement.refreshStatus
    parent()->refreshStatus();
}

void PowerManagementAdaptor::reparseConfiguration()
{
    // handle method call org.kde.Solid.PowerManagement.reparseConfiguration
    parent()->reparseConfiguration();
}

uint PowerManagementAdaptor::scheduleWakeup(const QString &service, const QDBusObjectPath &path, qulonglong timestamp)
{
    // handle method call org.kde.Solid.PowerManagement.scheduleWakeup
    return parent()->scheduleWakeup(service, path, timestamp);
}

qulonglong PowerManagementAdaptor::smoothedBatteryRemainingTime()
{
    // handle method call org.kde.Solid.PowerManagement.smoothedBatteryRemainingTime
    return parent()->smoothedBatteryRemainingTime();
}

void PowerManagementAdaptor::wakeup()
{
    // handle method call org.kde.Solid.PowerManagement.wakeup
    parent()->wakeup();
}


#include "moc_powermanagementadaptor.cpp"
