/****************************************************************************
** Meta object code from reading C++ file 'PowerDevilGlobalSettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../PowerDevilGlobalSettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PowerDevilGlobalSettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil14GlobalSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::GlobalSettings::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil14GlobalSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::GlobalSettings",
        "pausePlayersOnSuspendChanged",
        "",
        "BatteryLowLevelChanged",
        "BatteryCriticalLevelChanged",
        "BatteryCriticalActionChanged",
        "PeripheralBatteryLowLevelChanged",
        "BlockedInhibitionsChanged",
        "pausePlayersOnSuspend",
        "isPausePlayersOnSuspendImmutable",
        "defaultPausePlayersOnSuspendValue",
        "batteryLowLevel",
        "isBatteryLowLevelImmutable",
        "defaultBatteryLowLevelValue",
        "batteryCriticalLevel",
        "isBatteryCriticalLevelImmutable",
        "defaultBatteryCriticalLevelValue",
        "batteryCriticalAction",
        "isBatteryCriticalActionImmutable",
        "defaultBatteryCriticalActionValue",
        "peripheralBatteryLowLevel",
        "isPeripheralBatteryLowLevelImmutable",
        "defaultPeripheralBatteryLowLevelValue",
        "blockedInhibitions",
        "isBlockedInhibitionsImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pausePlayersOnSuspendChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BatteryLowLevelChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BatteryCriticalLevelChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BatteryCriticalActionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PeripheralBatteryLowLevelChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BlockedInhibitionsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pausePlayersOnSuspend'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isPausePlayersOnSuspendImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPausePlayersOnSuspendValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'batteryLowLevel'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isBatteryLowLevelImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBatteryLowLevelValue'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'batteryCriticalLevel'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isBatteryCriticalLevelImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBatteryCriticalLevelValue'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'batteryCriticalAction'
        QtMocHelpers::PropertyData<uint>(17, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isBatteryCriticalActionImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBatteryCriticalActionValue'
        QtMocHelpers::PropertyData<uint>(19, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'peripheralBatteryLowLevel'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isPeripheralBatteryLowLevelImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPeripheralBatteryLowLevelValue'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'blockedInhibitions'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isBlockedInhibitionsImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GlobalSettings, qt_meta_tag_ZN10PowerDevil14GlobalSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerDevil::GlobalSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14GlobalSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14GlobalSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil14GlobalSettingsE_t>.metaTypes,
    nullptr
} };

void PowerDevil::GlobalSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pausePlayersOnSuspendChanged(); break;
        case 1: _t->BatteryLowLevelChanged(); break;
        case 2: _t->BatteryCriticalLevelChanged(); break;
        case 3: _t->BatteryCriticalActionChanged(); break;
        case 4: _t->PeripheralBatteryLowLevelChanged(); break;
        case 5: _t->BlockedInhibitionsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalSettings::*)()>(_a, &GlobalSettings::pausePlayersOnSuspendChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalSettings::*)()>(_a, &GlobalSettings::BatteryLowLevelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalSettings::*)()>(_a, &GlobalSettings::BatteryCriticalLevelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalSettings::*)()>(_a, &GlobalSettings::BatteryCriticalActionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalSettings::*)()>(_a, &GlobalSettings::PeripheralBatteryLowLevelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalSettings::*)()>(_a, &GlobalSettings::BlockedInhibitionsChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->pausePlayersOnSuspend(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isPausePlayersOnSuspendImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultPausePlayersOnSuspendValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->batteryLowLevel(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isBatteryLowLevelImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultBatteryLowLevelValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->batteryCriticalLevel(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isBatteryCriticalLevelImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultBatteryCriticalLevelValue(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->batteryCriticalAction(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isBatteryCriticalActionImmutable(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->defaultBatteryCriticalActionValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->peripheralBatteryLowLevel(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isPeripheralBatteryLowLevelImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultPeripheralBatteryLowLevelValue(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->blockedInhibitions(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isBlockedInhibitionsImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPausePlayersOnSuspend(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setBatteryLowLevel(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setBatteryCriticalLevel(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setBatteryCriticalAction(*reinterpret_cast<uint*>(_v)); break;
        case 12: _t->setPeripheralBatteryLowLevel(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setBlockedInhibitions(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::GlobalSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::GlobalSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14GlobalSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int PowerDevil::GlobalSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::GlobalSettings::pausePlayersOnSuspendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PowerDevil::GlobalSettings::BatteryLowLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PowerDevil::GlobalSettings::BatteryCriticalLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PowerDevil::GlobalSettings::BatteryCriticalActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PowerDevil::GlobalSettings::PeripheralBatteryLowLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PowerDevil::GlobalSettings::BlockedInhibitionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
