/****************************************************************************
** Meta object code from reading C++ file 'powerdevilpowermanagement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.7.3/daemon/powerdevilpowermanagement.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerdevilpowermanagement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil15PowerManagementE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::PowerManagement::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil15PowerManagementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::PowerManagement",
        "canSuspendChanged",
        "",
        "canSuspendThenHibernateChanged",
        "canHibernateChanged",
        "canHybridSuspendChanged",
        "suspend",
        "hibernate",
        "hybridSuspend",
        "suspendThenHibernate",
        "canSuspend",
        "canHibernate",
        "canHybridSuspend",
        "canSuspendThenHibernate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'canSuspendChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSuspendThenHibernateChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canHibernateChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canHybridSuspendChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'suspend'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hibernate'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hybridSuspend'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'suspendThenHibernate'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'canSuspend'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'canHibernate'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'canHybridSuspend'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'canSuspendThenHibernate'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowerManagement, qt_meta_tag_ZN10PowerDevil15PowerManagementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerDevil::PowerManagement::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15PowerManagementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15PowerManagementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil15PowerManagementE_t>.metaTypes,
    nullptr
} };

void PowerDevil::PowerManagement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerManagement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->canSuspendChanged(); break;
        case 1: _t->canSuspendThenHibernateChanged(); break;
        case 2: _t->canHibernateChanged(); break;
        case 3: _t->canHybridSuspendChanged(); break;
        case 4: _t->suspend(); break;
        case 5: _t->hibernate(); break;
        case 6: _t->hybridSuspend(); break;
        case 7: _t->suspendThenHibernate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerManagement::*)()>(_a, &PowerManagement::canSuspendChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagement::*)()>(_a, &PowerManagement::canSuspendThenHibernateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagement::*)()>(_a, &PowerManagement::canHibernateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagement::*)()>(_a, &PowerManagement::canHybridSuspendChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canSuspend(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canHibernate(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canHybridSuspend(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canSuspendThenHibernate(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::PowerManagement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::PowerManagement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15PowerManagementE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerDevil::PowerManagement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::PowerManagement::canSuspendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PowerDevil::PowerManagement::canSuspendThenHibernateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PowerDevil::PowerManagement::canHibernateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PowerDevil::PowerManagement::canHybridSuspendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
