/****************************************************************************
** Meta object code from reading C++ file 'brightnesscontroladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "brightnesscontroladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'brightnesscontroladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24BrightnessControlAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto BrightnessControlAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN24BrightnessControlAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BrightnessControlAdaptor",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement.Actions.BrightnessControl",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Solid.PowerManagement.Actions.Brightne"
        "ssControl\">\n    <method name=\"setBrightness\">\n      <arg dire"
        "ction=\"in\" type=\"i\"/>\n    </method>\n    <method name=\"setBr"
        "ightnessSilent\">\n      <arg direction=\"in\" type=\"i\"/>\n    <"
        "/method>\n    <method name=\"brightness\">\n      <arg direction=\""
        "out\" type=\"i\"/>\n    </method>\n    <method name=\"brightnessMa"
        "x\">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n  "
        "  <method name=\"brightnessMin\">\n      <arg direction=\"out\" ty"
        "pe=\"i\"/>\n    </method>\n    <method name=\"knownSafeBrightnessM"
        "in\">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n "
        "   <signal name=\"brightnessChanged\">\n      <arg direction=\"out"
        "\" type=\"i\"/>\n    </signal>\n    <signal name=\"brightnessMaxCh"
        "anged\">\n      <arg direction=\"out\" type=\"i\"/>\n    </signal>"
        "\n    <signal name=\"brightnessMinChanged\">\n      <arg direction"
        "=\"out\" type=\"i\"/>\n    </signal>\n    <method name=\"brightnes"
        "sSteps\">\n      <arg direction=\"out\" type=\"i\"/>\n    </method"
        ">\n  </interface>\n",
        "brightnessChanged",
        "",
        "in0",
        "brightnessMaxChanged",
        "brightnessMinChanged",
        "brightness",
        "brightnessMax",
        "brightnessMin",
        "brightnessSteps",
        "knownSafeBrightnessMin",
        "setBrightness",
        "setBrightnessSilent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void(int)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'brightnessMaxChanged'
        QtMocHelpers::SignalData<void(int)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'brightnessMinChanged'
        QtMocHelpers::SignalData<void(int)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'brightness'
        QtMocHelpers::SlotData<int()>(10, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'brightnessMax'
        QtMocHelpers::SlotData<int()>(11, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'brightnessMin'
        QtMocHelpers::SlotData<int()>(12, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'brightnessSteps'
        QtMocHelpers::SlotData<int()>(13, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'knownSafeBrightnessMin'
        QtMocHelpers::SlotData<int()>(14, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setBrightness'
        QtMocHelpers::SlotData<void(int)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setBrightnessSilent'
        QtMocHelpers::SlotData<void(int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BrightnessControlAdaptor, qt_meta_tag_ZN24BrightnessControlAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BrightnessControlAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24BrightnessControlAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24BrightnessControlAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24BrightnessControlAdaptorE_t>.metaTypes,
    nullptr
} };

void BrightnessControlAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BrightnessControlAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->brightnessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->brightnessMaxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->brightnessMinChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: { int _r = _t->brightness();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->brightnessMax();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->brightnessMin();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->brightnessSteps();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->knownSafeBrightnessMin();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setBrightness((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->setBrightnessSilent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BrightnessControlAdaptor::*)(int )>(_a, &BrightnessControlAdaptor::brightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrightnessControlAdaptor::*)(int )>(_a, &BrightnessControlAdaptor::brightnessMaxChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrightnessControlAdaptor::*)(int )>(_a, &BrightnessControlAdaptor::brightnessMinChanged, 2))
            return;
    }
}

const QMetaObject *BrightnessControlAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BrightnessControlAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24BrightnessControlAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int BrightnessControlAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void BrightnessControlAdaptor::brightnessChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BrightnessControlAdaptor::brightnessMaxChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BrightnessControlAdaptor::brightnessMinChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
