// This file is generated by kconfig_compiler_kf6 from PowerDevilProfileSettings.kcfg.
// All changes you do to this file will be lost.

#include "PowerDevilProfileSettings.h"

using namespace PowerDevil;

ProfileSettings::ProfileSettings( const QString & ProfileId, bool IsMobile, bool IsVM, bool CanSuspend, QObject *parent )
  : KConfigSkeleton( QStringLiteral( "powerdevilrc" ) )
  , mParamProfileId(ProfileId)
  , mParamIsMobile(IsMobile)
  , mParamIsVM(IsVM)
  , mParamCanSuspend(CanSuspend)
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&ProfileSettings::itemChanged);

  KConfigGroup cgProfileId(this->config(), QStringLiteral( "%1" ).arg( mParamProfileId ));
  KConfigGroup cgKeyboard = cgProfileId.group(QStringLiteral( "Keyboard" ));
  KConfigCompilerSignallingItem  *itemUseProfileSpecificKeyboardBrightness;
  KConfigSkeleton::ItemBool  *innerItemUseProfileSpecificKeyboardBrightness;
  innerItemUseProfileSpecificKeyboardBrightness = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseProfileSpecificKeyboardBrightness" ), mUseProfileSpecificKeyboardBrightness, false );
  itemUseProfileSpecificKeyboardBrightness = new KConfigCompilerSignallingItem(innerItemUseProfileSpecificKeyboardBrightness, this, notifyFunction, signalUseProfileSpecificKeyboardBrightnessChanged);
  itemUseProfileSpecificKeyboardBrightness->setGroup(cgKeyboard);
  addItem( itemUseProfileSpecificKeyboardBrightness, QStringLiteral( "UseProfileSpecificKeyboardBrightness" ) );
  KConfigCompilerSignallingItem  *itemKeyboardBrightness;
  KConfigSkeleton::ItemInt  *innerItemKeyboardBrightness;
  innerItemKeyboardBrightness = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "KeyboardBrightness" ), mKeyboardBrightness, 50 );
  itemKeyboardBrightness = new KConfigCompilerSignallingItem(innerItemKeyboardBrightness, this, notifyFunction, signalKeyboardBrightnessChanged);
  itemKeyboardBrightness->setGroup(cgKeyboard);
  addItem( itemKeyboardBrightness, QStringLiteral( "KeyboardBrightness" ) );

  KConfigGroup cgDisplay = cgProfileId.group(QStringLiteral( "Display" ));
  KConfigCompilerSignallingItem  *itemUseProfileSpecificDisplayBrightness;
  KConfigSkeleton::ItemBool  *innerItemUseProfileSpecificDisplayBrightness;
  innerItemUseProfileSpecificDisplayBrightness = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseProfileSpecificDisplayBrightness" ), mUseProfileSpecificDisplayBrightness, 
                PowerDevil::ProfileDefaults::defaultUseProfileSpecificDisplayBrightness(mParamProfileId)
             );
  itemUseProfileSpecificDisplayBrightness = new KConfigCompilerSignallingItem(innerItemUseProfileSpecificDisplayBrightness, this, notifyFunction, signalUseProfileSpecificDisplayBrightnessChanged);
  itemUseProfileSpecificDisplayBrightness->setGroup(cgDisplay);
  addItem( itemUseProfileSpecificDisplayBrightness, QStringLiteral( "UseProfileSpecificDisplayBrightness" ) );
  KConfigCompilerSignallingItem  *itemDisplayBrightness;
  KConfigSkeleton::ItemInt  *innerItemDisplayBrightness;
  innerItemDisplayBrightness = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "DisplayBrightness" ), mDisplayBrightness, 
                PowerDevil::ProfileDefaults::defaultDisplayBrightness(mParamProfileId)
             );
  itemDisplayBrightness = new KConfigCompilerSignallingItem(innerItemDisplayBrightness, this, notifyFunction, signalDisplayBrightnessChanged);
  itemDisplayBrightness->setGroup(cgDisplay);
  addItem( itemDisplayBrightness, QStringLiteral( "DisplayBrightness" ) );
  KConfigCompilerSignallingItem  *itemDimDisplayWhenIdle;
  KConfigSkeleton::ItemBool  *innerItemDimDisplayWhenIdle;
  innerItemDimDisplayWhenIdle = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DimDisplayWhenIdle" ), mDimDisplayWhenIdle, 
                PowerDevil::ProfileDefaults::defaultDimDisplayWhenIdle()
             );
  itemDimDisplayWhenIdle = new KConfigCompilerSignallingItem(innerItemDimDisplayWhenIdle, this, notifyFunction, signalDimDisplayWhenIdleChanged);
  itemDimDisplayWhenIdle->setGroup(cgDisplay);
  addItem( itemDimDisplayWhenIdle, QStringLiteral( "DimDisplayWhenIdle" ) );
  KConfigCompilerSignallingItem  *itemDimDisplayIdleTimeoutSec;
  KConfigSkeleton::ItemInt  *innerItemDimDisplayIdleTimeoutSec;
  innerItemDimDisplayIdleTimeoutSec = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "DimDisplayIdleTimeoutSec" ), mDimDisplayIdleTimeoutSec, 
                PowerDevil::ProfileDefaults::defaultDimDisplayIdleTimeoutSec(mParamProfileId, mParamIsMobile)
             );
  itemDimDisplayIdleTimeoutSec = new KConfigCompilerSignallingItem(innerItemDimDisplayIdleTimeoutSec, this, notifyFunction, signalDimDisplayIdleTimeoutSecChanged);
  itemDimDisplayIdleTimeoutSec->setGroup(cgDisplay);
  addItem( itemDimDisplayIdleTimeoutSec, QStringLiteral( "DimDisplayIdleTimeoutSec" ) );
  KConfigCompilerSignallingItem  *itemTurnOffDisplayWhenIdle;
  KConfigSkeleton::ItemBool  *innerItemTurnOffDisplayWhenIdle;
  innerItemTurnOffDisplayWhenIdle = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TurnOffDisplayWhenIdle" ), mTurnOffDisplayWhenIdle, 
                PowerDevil::ProfileDefaults::defaultTurnOffDisplayWhenIdle()
             );
  itemTurnOffDisplayWhenIdle = new KConfigCompilerSignallingItem(innerItemTurnOffDisplayWhenIdle, this, notifyFunction, signalTurnOffDisplayWhenIdleChanged);
  itemTurnOffDisplayWhenIdle->setGroup(cgDisplay);
  addItem( itemTurnOffDisplayWhenIdle, QStringLiteral( "TurnOffDisplayWhenIdle" ) );
  KConfigCompilerSignallingItem  *itemTurnOffDisplayIdleTimeoutSec;
  KConfigSkeleton::ItemInt  *innerItemTurnOffDisplayIdleTimeoutSec;
  innerItemTurnOffDisplayIdleTimeoutSec = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TurnOffDisplayIdleTimeoutSec" ), mTurnOffDisplayIdleTimeoutSec, 
                PowerDevil::ProfileDefaults::defaultTurnOffDisplayIdleTimeoutSec(mParamProfileId, mParamIsMobile)
             );
  itemTurnOffDisplayIdleTimeoutSec = new KConfigCompilerSignallingItem(innerItemTurnOffDisplayIdleTimeoutSec, this, notifyFunction, signalTurnOffDisplayIdleTimeoutSecChanged);
  itemTurnOffDisplayIdleTimeoutSec->setGroup(cgDisplay);
  addItem( itemTurnOffDisplayIdleTimeoutSec, QStringLiteral( "TurnOffDisplayIdleTimeoutSec" ) );
  KConfigCompilerSignallingItem  *itemTurnOffDisplayIdleTimeoutWhenLockedSec;
  KConfigSkeleton::ItemInt  *innerItemTurnOffDisplayIdleTimeoutWhenLockedSec;
  innerItemTurnOffDisplayIdleTimeoutWhenLockedSec = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TurnOffDisplayIdleTimeoutWhenLockedSec" ), mTurnOffDisplayIdleTimeoutWhenLockedSec, 60 );
  itemTurnOffDisplayIdleTimeoutWhenLockedSec = new KConfigCompilerSignallingItem(innerItemTurnOffDisplayIdleTimeoutWhenLockedSec, this, notifyFunction, signalTurnOffDisplayIdleTimeoutWhenLockedSecChanged);
  itemTurnOffDisplayIdleTimeoutWhenLockedSec->setGroup(cgDisplay);
  addItem( itemTurnOffDisplayIdleTimeoutWhenLockedSec, QStringLiteral( "TurnOffDisplayIdleTimeoutWhenLockedSec" ) );
  KConfigCompilerSignallingItem  *itemLockBeforeTurnOffDisplay;
  KConfigSkeleton::ItemBool  *innerItemLockBeforeTurnOffDisplay;
  innerItemLockBeforeTurnOffDisplay = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LockBeforeTurnOffDisplay" ), mLockBeforeTurnOffDisplay, 
                PowerDevil::ProfileDefaults::defaultLockBeforeTurnOffDisplay(mParamIsMobile)
             );
  itemLockBeforeTurnOffDisplay = new KConfigCompilerSignallingItem(innerItemLockBeforeTurnOffDisplay, this, notifyFunction, signalLockBeforeTurnOffDisplayChanged);
  itemLockBeforeTurnOffDisplay->setGroup(cgDisplay);
  addItem( itemLockBeforeTurnOffDisplay, QStringLiteral( "LockBeforeTurnOffDisplay" ) );

  KConfigGroup cgSuspendAndShutdown = cgProfileId.group(QStringLiteral( "SuspendAndShutdown" ));
  KConfigCompilerSignallingItem  *itemAutoSuspendAction;
  KConfigSkeleton::ItemUInt  *innerItemAutoSuspendAction;
  innerItemAutoSuspendAction = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "AutoSuspendAction" ), mAutoSuspendAction, 
                PowerDevil::ProfileDefaults::defaultAutoSuspendAction(mParamIsVM, mParamCanSuspend)
             );
  itemAutoSuspendAction = new KConfigCompilerSignallingItem(innerItemAutoSuspendAction, this, notifyFunction, signalAutoSuspendActionChanged);
  itemAutoSuspendAction->setGroup(cgSuspendAndShutdown);
  addItem( itemAutoSuspendAction, QStringLiteral( "AutoSuspendAction" ) );
  KConfigCompilerSignallingItem  *itemAutoSuspendIdleTimeoutSec;
  KConfigSkeleton::ItemInt  *innerItemAutoSuspendIdleTimeoutSec;
  innerItemAutoSuspendIdleTimeoutSec = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AutoSuspendIdleTimeoutSec" ), mAutoSuspendIdleTimeoutSec, 
                PowerDevil::ProfileDefaults::defaultAutoSuspendIdleTimeoutSec(mParamProfileId, mParamIsMobile)
             );
  itemAutoSuspendIdleTimeoutSec = new KConfigCompilerSignallingItem(innerItemAutoSuspendIdleTimeoutSec, this, notifyFunction, signalAutoSuspendIdleTimeoutSecChanged);
  itemAutoSuspendIdleTimeoutSec->setGroup(cgSuspendAndShutdown);
  addItem( itemAutoSuspendIdleTimeoutSec, QStringLiteral( "AutoSuspendIdleTimeoutSec" ) );
  KConfigCompilerSignallingItem  *itemPowerButtonAction;
  KConfigSkeleton::ItemUInt  *innerItemPowerButtonAction;
  innerItemPowerButtonAction = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "PowerButtonAction" ), mPowerButtonAction, 
                PowerDevil::ProfileDefaults::defaultPowerButtonAction(mParamIsMobile)
             );
  itemPowerButtonAction = new KConfigCompilerSignallingItem(innerItemPowerButtonAction, this, notifyFunction, signalPowerButtonActionChanged);
  itemPowerButtonAction->setGroup(cgSuspendAndShutdown);
  addItem( itemPowerButtonAction, QStringLiteral( "PowerButtonAction" ) );
  KConfigCompilerSignallingItem  *itemPowerDownAction;
  KConfigSkeleton::ItemUInt  *innerItemPowerDownAction;
  innerItemPowerDownAction = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "PowerDownAction" ), mPowerDownAction, 
                PowerDevil::ProfileDefaults::defaultPowerDownAction()
             );
  itemPowerDownAction = new KConfigCompilerSignallingItem(innerItemPowerDownAction, this, notifyFunction, signalPowerDownActionChanged);
  itemPowerDownAction->setGroup(cgSuspendAndShutdown);
  addItem( itemPowerDownAction, QStringLiteral( "PowerDownAction" ) );
  KConfigCompilerSignallingItem  *itemLidAction;
  KConfigSkeleton::ItemUInt  *innerItemLidAction;
  innerItemLidAction = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "LidAction" ), mLidAction, 
                PowerDevil::ProfileDefaults::defaultLidAction(mParamIsVM, mParamCanSuspend)
             );
  itemLidAction = new KConfigCompilerSignallingItem(innerItemLidAction, this, notifyFunction, signalLidActionChanged);
  itemLidAction->setGroup(cgSuspendAndShutdown);
  addItem( itemLidAction, QStringLiteral( "LidAction" ) );
  KConfigCompilerSignallingItem  *itemInhibitLidActionWhenExternalMonitorPresent;
  KConfigSkeleton::ItemBool  *innerItemInhibitLidActionWhenExternalMonitorPresent;
  innerItemInhibitLidActionWhenExternalMonitorPresent = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "InhibitLidActionWhenExternalMonitorPresent" ), mInhibitLidActionWhenExternalMonitorPresent, true );
  itemInhibitLidActionWhenExternalMonitorPresent = new KConfigCompilerSignallingItem(innerItemInhibitLidActionWhenExternalMonitorPresent, this, notifyFunction, signalInhibitLidActionWhenExternalMonitorPresentChanged);
  itemInhibitLidActionWhenExternalMonitorPresent->setGroup(cgSuspendAndShutdown);
  addItem( itemInhibitLidActionWhenExternalMonitorPresent, QStringLiteral( "InhibitLidActionWhenExternalMonitorPresent" ) );
  KConfigCompilerSignallingItem  *itemSleepMode;
  KConfigSkeleton::ItemUInt  *innerItemSleepMode;
  innerItemSleepMode = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "SleepMode" ), mSleepMode, 
                qToUnderlying(PowerDevil::SleepMode::SuspendToRam)
             );
  itemSleepMode = new KConfigCompilerSignallingItem(innerItemSleepMode, this, notifyFunction, signalSleepModeChanged);
  itemSleepMode->setGroup(cgSuspendAndShutdown);
  addItem( itemSleepMode, QStringLiteral( "SleepMode" ) );

  KConfigGroup cgPerformance = cgProfileId.group(QStringLiteral( "Performance" ));
  KConfigCompilerSignallingItem  *itemPowerProfile;
  KConfigSkeleton::ItemString  *innerItemPowerProfile;
  innerItemPowerProfile = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PowerProfile" ), mPowerProfile );
  itemPowerProfile = new KConfigCompilerSignallingItem(innerItemPowerProfile, this, notifyFunction, signalPowerProfileChanged);
  itemPowerProfile->setGroup(cgPerformance);
  addItem( itemPowerProfile, QStringLiteral( "PowerProfile" ) );

  KConfigGroup cgRunScript = cgProfileId.group(QStringLiteral( "RunScript" ));
  KConfigCompilerSignallingItem  *itemProfileLoadCommand;
  KConfigSkeleton::ItemString  *innerItemProfileLoadCommand;
  innerItemProfileLoadCommand = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProfileLoadCommand" ), mProfileLoadCommand );
  itemProfileLoadCommand = new KConfigCompilerSignallingItem(innerItemProfileLoadCommand, this, notifyFunction, signalProfileLoadCommandChanged);
  itemProfileLoadCommand->setGroup(cgRunScript);
  addItem( itemProfileLoadCommand, QStringLiteral( "ProfileLoadCommand" ) );
  KConfigCompilerSignallingItem  *itemProfileUnloadCommand;
  KConfigSkeleton::ItemString  *innerItemProfileUnloadCommand;
  innerItemProfileUnloadCommand = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProfileUnloadCommand" ), mProfileUnloadCommand );
  itemProfileUnloadCommand = new KConfigCompilerSignallingItem(innerItemProfileUnloadCommand, this, notifyFunction, signalProfileUnloadCommandChanged);
  itemProfileUnloadCommand->setGroup(cgRunScript);
  addItem( itemProfileUnloadCommand, QStringLiteral( "ProfileUnloadCommand" ) );
  KConfigCompilerSignallingItem  *itemIdleTimeoutCommand;
  KConfigSkeleton::ItemString  *innerItemIdleTimeoutCommand;
  innerItemIdleTimeoutCommand = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "IdleTimeoutCommand" ), mIdleTimeoutCommand );
  itemIdleTimeoutCommand = new KConfigCompilerSignallingItem(innerItemIdleTimeoutCommand, this, notifyFunction, signalIdleTimeoutCommandChanged);
  itemIdleTimeoutCommand->setGroup(cgRunScript);
  addItem( itemIdleTimeoutCommand, QStringLiteral( "IdleTimeoutCommand" ) );
  KConfigCompilerSignallingItem  *itemRunScriptIdleTimeoutSec;
  KConfigSkeleton::ItemInt  *innerItemRunScriptIdleTimeoutSec;
  innerItemRunScriptIdleTimeoutSec = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "RunScriptIdleTimeoutSec" ), mRunScriptIdleTimeoutSec, 600 );
  itemRunScriptIdleTimeoutSec = new KConfigCompilerSignallingItem(innerItemRunScriptIdleTimeoutSec, this, notifyFunction, signalRunScriptIdleTimeoutSecChanged);
  itemRunScriptIdleTimeoutSec->setGroup(cgRunScript);
  addItem( itemRunScriptIdleTimeoutSec, QStringLiteral( "RunScriptIdleTimeoutSec" ) );
}

bool ProfileSettings::defaultUseProfileSpecificKeyboardBrightnessValue_helper() const
{

  return false;
}

int ProfileSettings::defaultKeyboardBrightnessValue_helper() const
{

  return 50;
}

bool ProfileSettings::defaultUseProfileSpecificDisplayBrightnessValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultUseProfileSpecificDisplayBrightness(mParamProfileId)
            ;
}

int ProfileSettings::defaultDisplayBrightnessValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultDisplayBrightness(mParamProfileId)
            ;
}

bool ProfileSettings::defaultDimDisplayWhenIdleValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultDimDisplayWhenIdle()
            ;
}

int ProfileSettings::defaultDimDisplayIdleTimeoutSecValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultDimDisplayIdleTimeoutSec(mParamProfileId, mParamIsMobile)
            ;
}

bool ProfileSettings::defaultTurnOffDisplayWhenIdleValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultTurnOffDisplayWhenIdle()
            ;
}

int ProfileSettings::defaultTurnOffDisplayIdleTimeoutSecValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultTurnOffDisplayIdleTimeoutSec(mParamProfileId, mParamIsMobile)
            ;
}

int ProfileSettings::defaultTurnOffDisplayIdleTimeoutWhenLockedSecValue_helper() const
{

  return 60;
}

bool ProfileSettings::defaultLockBeforeTurnOffDisplayValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultLockBeforeTurnOffDisplay(mParamIsMobile)
            ;
}

uint ProfileSettings::defaultAutoSuspendActionValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultAutoSuspendAction(mParamIsVM, mParamCanSuspend)
            ;
}

int ProfileSettings::defaultAutoSuspendIdleTimeoutSecValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultAutoSuspendIdleTimeoutSec(mParamProfileId, mParamIsMobile)
            ;
}

uint ProfileSettings::defaultPowerButtonActionValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultPowerButtonAction(mParamIsMobile)
            ;
}

uint ProfileSettings::defaultPowerDownActionValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultPowerDownAction()
            ;
}

uint ProfileSettings::defaultLidActionValue_helper() const
{

  return 
                PowerDevil::ProfileDefaults::defaultLidAction(mParamIsVM, mParamCanSuspend)
            ;
}

bool ProfileSettings::defaultInhibitLidActionWhenExternalMonitorPresentValue_helper() const
{

  return true;
}

uint ProfileSettings::defaultSleepModeValue_helper() const
{

  return 
                qToUnderlying(PowerDevil::SleepMode::SuspendToRam)
            ;
}

int ProfileSettings::defaultRunScriptIdleTimeoutSecValue_helper() const
{

  return 600;
}

ProfileSettings::~ProfileSettings()
{
}


void ProfileSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalUseProfileSpecificKeyboardBrightnessChanged:
    Q_EMIT UseProfileSpecificKeyboardBrightnessChanged();
    break;
  case signalKeyboardBrightnessChanged:
    Q_EMIT KeyboardBrightnessChanged();
    break;
  case signalUseProfileSpecificDisplayBrightnessChanged:
    Q_EMIT UseProfileSpecificDisplayBrightnessChanged();
    break;
  case signalDisplayBrightnessChanged:
    Q_EMIT DisplayBrightnessChanged();
    break;
  case signalDimDisplayWhenIdleChanged:
    Q_EMIT DimDisplayWhenIdleChanged();
    break;
  case signalDimDisplayIdleTimeoutSecChanged:
    Q_EMIT DimDisplayIdleTimeoutSecChanged();
    break;
  case signalTurnOffDisplayWhenIdleChanged:
    Q_EMIT TurnOffDisplayWhenIdleChanged();
    break;
  case signalTurnOffDisplayIdleTimeoutSecChanged:
    Q_EMIT TurnOffDisplayIdleTimeoutSecChanged();
    break;
  case signalTurnOffDisplayIdleTimeoutWhenLockedSecChanged:
    Q_EMIT TurnOffDisplayIdleTimeoutWhenLockedSecChanged();
    break;
  case signalLockBeforeTurnOffDisplayChanged:
    Q_EMIT LockBeforeTurnOffDisplayChanged();
    break;
  case signalAutoSuspendActionChanged:
    Q_EMIT AutoSuspendActionChanged();
    break;
  case signalAutoSuspendIdleTimeoutSecChanged:
    Q_EMIT AutoSuspendIdleTimeoutSecChanged();
    break;
  case signalPowerButtonActionChanged:
    Q_EMIT PowerButtonActionChanged();
    break;
  case signalPowerDownActionChanged:
    Q_EMIT PowerDownActionChanged();
    break;
  case signalLidActionChanged:
    Q_EMIT LidActionChanged();
    break;
  case signalInhibitLidActionWhenExternalMonitorPresentChanged:
    Q_EMIT InhibitLidActionWhenExternalMonitorPresentChanged();
    break;
  case signalSleepModeChanged:
    Q_EMIT SleepModeChanged();
    break;
  case signalPowerProfileChanged:
    Q_EMIT PowerProfileChanged();
    break;
  case signalProfileLoadCommandChanged:
    Q_EMIT ProfileLoadCommandChanged();
    break;
  case signalProfileUnloadCommandChanged:
    Q_EMIT ProfileUnloadCommandChanged();
    break;
  case signalIdleTimeoutCommandChanged:
    Q_EMIT IdleTimeoutCommandChanged();
    break;
  case signalRunScriptIdleTimeoutSecChanged:
    Q_EMIT RunScriptIdleTimeoutSecChanged();
    break;
  }
}
