/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.PowerProfile.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef POWERPROFILEADAPTOR_H
#define POWERPROFILEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "powerprofile.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Solid.PowerManagement.Actions.PowerProfile
 */
class PowerProfileAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement.Actions.PowerProfile")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Solid.PowerManagement.Actions.PowerProfile\">\n"
"    <method name=\"configuredProfile\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"currentProfile\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"profileChoices\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setProfile\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"performanceInhibitedReason\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"performanceDegradedReason\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"profileHolds\">\n"
"      <arg direction=\"out\" type=\"aa{sv}\"/>\n"
"      <annotation value=\"QList&lt;QVariantMap&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"holdProfile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"profile\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"reason\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"application_id\"/>\n"
"      <arg direction=\"out\" type=\"u\" name=\"cookie\"/>\n"
"    </method>\n"
"    <method name=\"releaseProfile\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"cookie\"/>\n"
"    </method>\n"
"    <signal name=\"configuredProfileChanged\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"currentProfileChanged\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"profileChoicesChanged\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </signal>\n"
"    <signal name=\"performanceInhibitedReasonChanged\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"performanceDegradedReasonChanged\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"profileHoldsChanged\">\n"
"      <arg direction=\"out\" type=\"aa{sv}\"/>\n"
"      <annotation value=\"QList&lt;QVariantMap&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    PowerProfileAdaptor(PowerDevil::BundledActions::PowerProfile *parent);
    ~PowerProfileAdaptor() override;

    inline PowerDevil::BundledActions::PowerProfile *parent() const
    { return static_cast<PowerDevil::BundledActions::PowerProfile *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString configuredProfile();
    QString currentProfile();
    uint holdProfile(const QString &profile, const QString &reason, const QString &application_id);
    QString performanceDegradedReason();
    QString performanceInhibitedReason();
    QStringList profileChoices();
    QList<QVariantMap> profileHolds();
    void releaseProfile(uint cookie);
    void setProfile(const QString &in0);
Q_SIGNALS: // SIGNALS
    void configuredProfileChanged(const QString &in0);
    void currentProfileChanged(const QString &in0);
    void performanceDegradedReasonChanged(const QString &in0);
    void performanceInhibitedReasonChanged(const QString &in0);
    void profileChoicesChanged(const QStringList &in0);
    void profileHoldsChanged(const QList<QVariantMap> &in0);
};

#endif
