/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.PowerManagement.Inhibit.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef POWERMANAGEMENTINHIBITADAPTOR_H
#define POWERMANAGEMENTINHIBITADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "powerdevilfdoconnector.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.PowerManagement.Inhibit
 */
class PowerManagementInhibitAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.PowerManagement.Inhibit")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.PowerManagement.Inhibit\">\n"
"    <method name=\"Inhibit\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"application\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"reason\"/>\n"
"      <arg direction=\"out\" type=\"u\" name=\"cookie\"/>\n"
"    </method>\n"
"    <method name=\"UnInhibit\">\n"
"      <arg direction=\"in\" type=\"u\" name=\"cookie\"/>\n"
"    </method>\n"
"    <signal name=\"HasInhibitChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"has_inhibit\"/>\n"
"    </signal>\n"
"    <method name=\"HasInhibit\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"has_inhibit\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    PowerManagementInhibitAdaptor(PowerDevil::FdoConnector *parent);
    ~PowerManagementInhibitAdaptor() override;

    inline PowerDevil::FdoConnector *parent() const
    { return static_cast<PowerDevil::FdoConnector *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool HasInhibit();
    uint Inhibit(const QString &application, const QString &reason);
    void UnInhibit(uint cookie);
Q_SIGNALS: // SIGNALS
    void HasInhibitChanged(bool has_inhibit);
};

#endif
