/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef POWERMANAGEMENTADAPTOR_H
#define POWERMANAGEMENTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "powerdevilcore.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Solid.PowerManagement
 */
class PowerManagementAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Solid.PowerManagement\">\n"
"    <method name=\"refreshStatus\"/>\n"
"    <method name=\"reparseConfiguration\"/>\n"
"    <method name=\"backendCapabilities\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"    </method>\n"
"    <method name=\"loadProfile\">\n"
"      <arg direction=\"in\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"currentProfile\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"batteryRemainingTime\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </method>\n"
"    <method name=\"smoothedBatteryRemainingTime\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </method>\n"
"    <method name=\"isLidClosed\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isLidPresent\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isActionSupported\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"hasDualGpu\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isBatteryConservationModeEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"chargeStartThreshold\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"chargeStopThreshold\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"scheduleWakeup\">\n"
"      <arg direction=\"out\" type=\"u\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"service\"/>\n"
"      <arg direction=\"in\" type=\"o\" name=\"path\"/>\n"
"      <arg direction=\"in\" type=\"t\" name=\"timestamp\"/>\n"
"    </method>\n"
"    <method name=\"wakeup\"/>\n"
"    <method name=\"clearWakeup\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <signal name=\"profileChanged\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"configurationReloaded\"/>\n"
"    <signal name=\"batteryRemainingTimeChanged\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </signal>\n"
"    <signal name=\"smoothedBatteryRemainingTimeChanged\">\n"
"      <arg direction=\"out\" type=\"t\"/>\n"
"    </signal>\n"
"    <signal name=\"lidClosedChanged\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </signal>\n"
"    <signal name=\"batteryConservationModeChanged\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </signal>\n"
"    <signal name=\"chargeStartThresholdChanged\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </signal>\n"
"    <signal name=\"chargeStopThresholdChanged\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </signal>\n"
"    <signal name=\"supportedActionsChanged\"/>\n"
"  </interface>\n"
        "")
public:
    PowerManagementAdaptor(PowerDevil::Core *parent);
    ~PowerManagementAdaptor() override;

    inline PowerDevil::Core *parent() const
    { return static_cast<PowerDevil::Core *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    uint backendCapabilities();
    qulonglong batteryRemainingTime();
    int chargeStartThreshold();
    int chargeStopThreshold();
    void clearWakeup(int in0);
    QString currentProfile();
    bool hasDualGpu();
    bool isActionSupported(const QString &in0);
    bool isBatteryConservationModeEnabled();
    bool isLidClosed();
    bool isLidPresent();
    void loadProfile(bool in0);
    void refreshStatus();
    void reparseConfiguration();
    uint scheduleWakeup(const QString &service, const QDBusObjectPath &path, qulonglong timestamp);
    qulonglong smoothedBatteryRemainingTime();
    void wakeup();
Q_SIGNALS: // SIGNALS
    void batteryConservationModeChanged(bool in0);
    void batteryRemainingTimeChanged(qulonglong in0);
    void chargeStartThresholdChanged(int in0);
    void chargeStopThresholdChanged(int in0);
    void configurationReloaded();
    void lidClosedChanged(bool in0);
    void profileChanged(const QString &in0);
    void smoothedBatteryRemainingTimeChanged(qulonglong in0);
    void supportedActionsChanged();
};

#endif
