/****************************************************************************
** Meta object code from reading C++ file 'handlebuttonevents.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../powerdevil-6.7.3/daemon/actions/bundled/handlebuttonevents.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'handlebuttonevents.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil14BundledActions18HandleButtonEventsE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::BundledActions::HandleButtonEvents::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil14BundledActions18HandleButtonEventsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::BundledActions::HandleButtonEvents",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement.Actions.HandleButtonEvents",
        "triggersLidActionChanged",
        "",
        "triggers",
        "lidAction",
        "triggersLidAction",
        "onLidClosedChanged",
        "closed",
        "powerOffButtonTriggered",
        "powerDownButtonTriggered",
        "sleep",
        "hibernate",
        "checkOutputs",
        "onResumeFromSuspend",
        "checkWakeup",
        "reactToDisplayHotunplug"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'triggersLidActionChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'lidAction'
        QtMocHelpers::SlotData<int() const>(6, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'triggersLidAction'
        QtMocHelpers::SlotData<bool() const>(7, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'onLidClosedChanged'
        QtMocHelpers::SlotData<void(bool)>(8, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'powerOffButtonTriggered'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'powerDownButtonTriggered'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sleep'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'hibernate'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkOutputs'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onResumeFromSuspend'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkWakeup'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reactToDisplayHotunplug'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<HandleButtonEvents, qt_meta_tag_ZN10PowerDevil14BundledActions18HandleButtonEventsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerDevil::BundledActions::HandleButtonEvents::staticMetaObject = { {
    QMetaObject::SuperData::link<PowerDevil::Action::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions18HandleButtonEventsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions18HandleButtonEventsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil14BundledActions18HandleButtonEventsE_t>.metaTypes,
    nullptr
} };

void PowerDevil::BundledActions::HandleButtonEvents::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HandleButtonEvents *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->triggersLidActionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: { int _r = _t->lidAction();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->triggersLidAction();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->onLidClosedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->powerOffButtonTriggered(); break;
        case 5: _t->powerDownButtonTriggered(); break;
        case 6: _t->sleep(); break;
        case 7: _t->hibernate(); break;
        case 8: _t->checkOutputs(); break;
        case 9: _t->onResumeFromSuspend(); break;
        case 10: _t->checkWakeup(); break;
        case 11: _t->reactToDisplayHotunplug(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HandleButtonEvents::*)(bool )>(_a, &HandleButtonEvents::triggersLidActionChanged, 0))
            return;
    }
}

const QMetaObject *PowerDevil::BundledActions::HandleButtonEvents::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::BundledActions::HandleButtonEvents::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions18HandleButtonEventsE_t>.strings))
        return static_cast<void*>(this);
    return PowerDevil::Action::qt_metacast(_clname);
}

int PowerDevil::BundledActions::HandleButtonEvents::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PowerDevil::Action::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::BundledActions::HandleButtonEvents::triggersLidActionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
